@@ -8,13 +8,16 @@ def restart_apache():
     run('/etc/init.d/apache2 restart')
 
 def touch():
+    """ Reloads source code by touching the wsgi file """
     run('touch %s/hosting/generated/django.wsgi' % env.conf['SRC_DIR'])
 
 def pip_install(what='active', options=''):
+    """ Installs pip requirements listed in reqs/<file>.txt file. """
     run('pip install %s -E %s -r %s/reqs/%s.txt' % (options, env.conf['ENV_DIR'], env.conf['SRC_DIR'], what))
     touch()
 
 def pip_update(what='active', options='', restart=True):
+    """ Updates pip requirements listed in reqs/<file>.txt file. """
     run('pip install %s -U -E %s -r %s/reqs/%s.txt' % (options, env.conf['ENV_DIR'], env.conf['SRC_DIR'], what))
     if restart:
         touch()
@@ -27,5 +30,6 @@ def mysqldump(dir='hosting/backups'):
         run('mysqldump -uroot -p%s %s > %s/%s%s.sql' % (password, db, dir, db, now))
 
 def delete_pyc():
+    """ Deletes *.pyc files from project source dir """
     with cd(env.conf['SRC_DIR']):
         run("find . -name '*.pyc' -delete")
