@@ -32,7 +32,15 @@ def make_virtualenv():
 
 
 def push(*args):
-    ''' Run it instead of hg push. '''
+    ''' Run it instead of hg push.
+    Arguments:
+      * force - run all actions even if nothing changes
+      * notest - don't run tests
+      * syncdb - run syncdb before code reloading
+      * migrate - run migrate before code reloading
+      * pip_update - run pip_update before code reloading
+      * norestart - do not reload source code
+    '''
     allowed_args = set(['force', 'notest', 'syncdb', 'migrate', 'pip_update', 'norestart'])
     for arg in args:
         if arg not in allowed_args:
