@@ -15,17 +15,17 @@ def migrate(params='', do_backup=True):
         mysqldump('hosting/backups/before-migrate')
     manage('migrate --noinput %s' % params)
 
-def syncdb():
-    manage('syncdb --noinput')
+def syncdb(params=''):
+    manage('syncdb --noinput %s' % params)
 
-def compress():
+def compress(params=''):
     with settings(warn_only=True):
-        manage('synccompress')
+        manage('synccompress %s' % params)
 
-def test():
-    pass
-#    with cd(env.conf['SRC_DIR']):
-#        run('source %s/bin/activate; ./bin/runtests.sh' % env.conf['ENV_DIR'])
+def test(what=''):
+    with settings(warn_only=True):
+        with cd(env.conf['SRC_DIR']):
+            run('source %s/bin/activate; ./runtests.sh %s' % (env.conf['ENV_DIR'], what))
 
 def coverage():
     pass
