@@ -40,6 +40,8 @@ def update_env():
         SRC_BASE = SRC_BASE,
         ENV_DIR = HOME_DIR + '/' + ENV_BASE + '/' + env.conf['INSTANCE_NAME'],
         SRC_DIR = HOME_DIR + '/' + SRC_BASE + '/' + env.conf['INSTANCE_NAME'],
+        USER = env.user,
+        HOST = env.hosts[0],
     )
     defaults.update(env.conf)
     env.conf = defaults
